Changelog
=========


1.0a5 (2021-11-16)
------------------

- Add cropping support on File content type
  [laulaz]


1.0a4 (2021-11-05)
------------------

- Add `collective.solr` dependency & Activate SolR search by default
  [mpeeters]

- Add pas.plugins.imio profile dependency
  [laulaz]

- Hide plone.keywords for non editors
  [laulaz]

- Add topics & page category on File content type
  [laulaz]

- Allow only listing_view on collections
  [laulaz]

- Make Collections globally addable
  [laulaz]

- TinyMCE config is now made in imio.smartweb.common
  [laulaz]

- Simplify TinyMCE config & force paste as text
  [laulaz]

- Allow PortalPage content as default view
  [laulaz]

- Display Collection in navigation by default
  [laulaz]

- Move localmessages viewlet from default abovecontent to portalheader viewlet manager
  [boulch]

- Rename dependency : collective.bigbang to collective.bigbang
  [boulch]

- Manage grouping/order/visibility of subsite/minisite header/footer viewlets
  [laulaz]

- Allow only useful image scales in TinyMCE text fields
  [laulaz]

- Move code to imio.smartweb.common
  [laulaz]

- Remove collective.pivot out of metadata (undo auto-install)
  [boulch]


1.0a3 (2021-06-29)
------------------

- Add imio.gdpr
  [boulch]

- Add collective.messagesviewlet
  [boulch]

- Add pas.plugins.imio.
  [bsuttor]

- Add collective.bigbang.
  [bsuttor]


1.0a2 (2021-04-22)
------------------

- WEBMIGP5-12: Override TinyMCE Formats inline items
  [laulaz]

- WEBMIGP5-14: Change images behaviors
  [laulaz]

- WEBMIGP5-13: Change files behaviors
  [laulaz]

- Add configuration for TinyMCE toolbars / menus
  [laulaz]

- Add basic demo profile with content creation & improve install profile
  [laulaz]

- Fix navigation links translations
  [laulaz]

- Change header viewlets default order
  [laulaz]

- Migrate & improve buildout for Plone 6
  [boulch]

- Add uninstall profile
  [boulch]

- Fix tests for Plone 6
  [boulch]


1.0a1 (2021-04-19)
------------------

- Initial release.
  [boulch]
